# Quicklogic

The {py:mod}`torii.platform.vendor.quicklogic` module provides a base platform to support Quicklogic devices with [Symbiflow] toolchain.
```{eval-rst}

.. autoclass:: torii.platform.vendor.quicklogic.QuicklogicPlatform

```

[Symbiflow]: https://github.com/QuickLogic-Corp/quicklogic-fpga-toolchain
